@@ -8,6 +8,7 @@ tmuxp.session
 from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
+import os
 import pipes
 import logging
 
@@ -161,10 +162,10 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
         )
 
         if start_directory:
-            self.tmux('set-option', 'default-path', start_directory)
-            self.server.tmux('set-option', 'default-path', start_directory)
-            # start_directory = pipes.quote(start_directory)
-            # window_args += ('-c%s' % start_directory,)
+            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
+            start_directory = os.path.expanduser(start_directory)
+            start_directory = pipes.quote(start_directory)
+            window_args += ('-c%s' % start_directory,)
 
         window_args += (
             '-F"%s"' % '\t'.join(tmux_formats),  # output
